extrapolate_line

Function extrapolate_line 

pub fn extrapolate_line<F: FieldOps>(x0: F, x1: F, z: F) -> F
Extrapolates a line through two points.

The two points are (0, x_0) and (1, x_1). The line through them, evaluated at the parameter z, is

x_0 + (x_1 - x_0) * z

The two points are also the halves a variable splits a multilinear into. Read that way, this binds that variable to z.